@@ -10,7 +10,6 @@
 #' @param calculations Returns year-over-year calculations if set to TRUE.
 #' @param annualaverage Retruns an annual average if set to TRUE.
 #' @keywords bls api economics cpi unemployment inflation
-#' @importFrom data.table rbindlist
 #' @importFrom jsonlite toJSON
 #' @importFrom httr content POST content_type_json
 #' @export bls_api
@@ -51,6 +50,12 @@ bls_api <- function (seriesid, startyear = NULL, endyear = NULL, registrationKey
     year=period=':='=seriesID=NULL
     # Begin constructing payload.
     payload <- list(seriesid = seriesid)
+    # Check for start and end years
+    if (!is.null(startyear) & is.null(endyear)){
+        endyear <- format(Sys.Date(), "%Y")
+        message("The API requires both a start and end year." 
+                ,"\nThe endyear argument has automatically been set to ", format(Sys.Date(), "%Y"),".")
+    }
     # Payload won't take NULL values, have to check every field.
     # Probably a more elegant way do do this using an apply function.
     if (exists("registrationKey") & !is.null(registrationKey)){
@@ -102,30 +107,21 @@ bls_api <- function (seriesid, startyear = NULL, endyear = NULL, registrationKey
     jsondat <- httr::content(httr::POST(base_url, body = payload, httr::content_type_json()))
     
     if(length(jsondat$Results) > 0) {
-        # Put results into data.table format.
-        # Try to figure out a way to do this without importing data.table with the package.
-        # Method borrowed from here:
-        # https://github.com/fcocquemas/bulast/blob/master/R/bulast.R
-        dt <- data.table::rbindlist(lapply(jsondat$Results$series, function(s) {
-            dt <- rbindlist(lapply(s$data, function(d) {
+        dt <- do.call("rbind",lapply(jsondat$Results$series, function(s) {
+            dt <- do.call("rbind", lapply(s$data, function(d) {
                 d[["footnotes"]] <- paste(unlist(d[["footnotes"]]), collapse = " ")
+                d[["seriesID"]] <- paste(unlist(s[["seriesID"]]), collapse = " ")
                 d <- lapply(lapply(d, unlist), paste, collapse=" ")
-            }), use.names = TRUE, fill=TRUE)
-            dt[, seriesID := s[["seriesID"]]]
-            dt
-        }), use.names = TRUE, fill=TRUE)
-        
+            }))
+        }))
         jsondat$Results <- dt
-        # Convert year and period to date. Remove annual averages.
-        if ("period" %in% colnames(dt)){
-            dt[, date := seq(as.Date(paste(year, ifelse(period == "M13", 12, substr(period, 2, 3)), "01", sep = "-")),
-                             length = 2, by = "months")[2]-1,by="year,period"]
-        }
         df <- as.data.frame(jsondat$Results)
         df$value <- as.numeric(as.character(df$value))
+        
         if ("year" %in% colnames(df)){
-        df$year <- as.numeric(as.character(df$year))
+            df$year <- as.numeric(as.character(df$year))
         }
+        
         if (nrow(df)==0){
             stop(print(jsondat$message),
                  print(jsondat$status))
@@ -134,7 +130,3 @@ bls_api <- function (seriesid, startyear = NULL, endyear = NULL, registrationKey
     return(df)
 }
 
-
-
-
-
